from wagtail.blocks import *
# from wagtail.images.blocks import ImageBlock
from wagtail.images.blocks import ImageChooserBlock

from wagtail_color_panel.blocks import NativeColorBlock
from wagtail.embeds.blocks import EmbedBlock
from wagtailcodeblock.blocks import CodeBlock

from core.common import ParagraphBlock,HeadingBlock,HRLine,LineBreak,QuoteBlock,CTA
from core.common import ALIGNMENT_LIST,FONT_SIZE_LIST

class HighlightHeadingBlock(StructBlock):
    title = CharBlock()
    alignment = ChoiceBlock(choices=ALIGNMENT_LIST, required=False,default="text-left")
    size = ChoiceBlock(choices=FONT_SIZE_LIST, required=False,default="text-base")
    bg=NativeColorBlock(default="#FFFFFF",required=False)
    fg=NativeColorBlock(default="#000000",required=False)
    
class ImageHeadingBlock(StructBlock):
    image=ImageChooserBlock(required=False)
    icon = CharBlock(required=False)
    iconSize = ChoiceBlock(choices=FONT_SIZE_LIST, required=False,default="text-lg",label="Icon Size")
    title = CharBlock()
    alignment = ChoiceBlock(choices=ALIGNMENT_LIST, required=False,default="text-left")
    size = ChoiceBlock(choices=FONT_SIZE_LIST, required=False,default="text-base")
    

class BaseColumnBlock(StreamBlock):
    heading = HeadingBlock(required=False)
    highlight_heading=HighlightHeadingBlock(required=False,label="Highlight Heading")
    image_heading=ImageHeadingBlock(required=False,label="Icon + Heading")
    hr_line = HRLine(required=False)
    line_break = LineBreak(required=False)
    paragraph = ParagraphBlock(required=False)
    cta = CTA(required=False)
    image = ImageChooserBlock(required=False)
    quote = QuoteBlock(required=False)
    embed = EmbedBlock(max_width=800, max_height=400,label="Video")
    code=CodeBlock(label='Code')

class BaseRowBlock(StructBlock):
    bgColor = NativeColorBlock(default="#000000", label="BG Color")
    fgColor = NativeColorBlock(default="#FFFFFF", label="FG Color")
    title = CharBlock(required=False)

    content = StreamBlock(
        [
            ("column", BaseColumnBlock(required=False))
        ]
    )

class ColumnBlock(BaseColumnBlock):

    sub_row = BaseRowBlock(required=False)

class RowBlock(StructBlock):
    bgColor = NativeColorBlock(default="#FFFFFF", label="BG Color")
    fgColor = NativeColorBlock(default="#000000", label="FG Color")
    title = CharBlock(required=False)

    content = StreamBlock(
        [
            ("column", ColumnBlock(required=False))
        ], required=False
    )

class SectionBlock(StructBlock):
    bgColor = NativeColorBlock(default="#FFFFFF", label="BG Color")
    fgColor = NativeColorBlock(default="#000000", label="FG Color")
    title = CharBlock(required=False)
    content = StreamBlock(
        [
            ("heading", HeadingBlock(required=False)),
            ("highlight_heading", HighlightHeadingBlock(required=False,label="Highlight Heading")),
            ("image_heading", ImageHeadingBlock(required=False,label="Icon + Heading")),
            ("hr_line", HRLine(required=False)),
            ("line_break", LineBreak(required=False)),
            ('cta', CTA(required=False)),
            ("paragraph", ParagraphBlock(required=False)),
            ("image", ImageChooserBlock(required=False)),
            ("quote", QuoteBlock(required=False)),
            ("embed", EmbedBlock(required=False,label="Video")),
            ("code", CodeBlock(label='Code',default_language='python')),
        ], required=False
    )


